<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AppMgmtDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1303"/>
        <source>Manage External Applications</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1315"/>
        <source>Name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1317"/>
        <source>Application path and arguments</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1323"/>
        <source>Choose</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1327"/>
        <source>Add manually</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1331"/>
        <source>Remove</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1338"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1378"/>
        <source>Choose Application</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1390"/>
        <source>New Application</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ColorsDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1008"/>
        <source>Colors</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1014"/>
        <source>Reset</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1019"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1027"/>
        <source>Hue</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1028"/>
        <source>Saturation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1029"/>
        <source>Lightness</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1038"/>
        <source>Colorize</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1042"/>
        <location filename="../dialogs.cpp" line="1046"/>
        <location filename="../dialogs.cpp" line="1050"/>
        <source>Negative</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1069"/>
        <location filename="../dialogs.cpp" line="1135"/>
        <source>Red</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1074"/>
        <location filename="../dialogs.cpp" line="1143"/>
        <source>Green</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1079"/>
        <location filename="../dialogs.cpp" line="1151"/>
        <source>Blue</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1096"/>
        <source>Hue and Saturation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1102"/>
        <source>Affected Channels</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1106"/>
        <source>Brightness</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1107"/>
        <source>Contrast</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1131"/>
        <source>Brightness and Contrast</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1171"/>
        <source>Color Balance</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>CopyMoveToDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1407"/>
        <source>Move to...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1410"/>
        <source>Copy to...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1438"/>
        <source>Browse...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1440"/>
        <source>Remove</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1447"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1452"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1463"/>
        <location filename="../dialogs.cpp" line="1489"/>
        <source>Destination:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1529"/>
        <source>Choose Folder</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>CpMvDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="28"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="113"/>
        <location filename="../dialogs.cpp" line="141"/>
        <source>Copying &quot;%1&quot; to &quot;%2&quot;.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="113"/>
        <location filename="../dialogs.cpp" line="142"/>
        <source>Moving &quot;%1&quot; to &quot;%2&quot;.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>CropDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="688"/>
        <source>Cropping</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="696"/>
        <source>Reset</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="699"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="735"/>
        <source>Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="736"/>
        <source>Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="737"/>
        <source>Top</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="738"/>
        <source>Bottom</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ImageTags</name>
    <message>
        <location filename="../tags.cpp" line="59"/>
        <source>Tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="63"/>
        <source>Untag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="73"/>
        <source>Clear Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="66"/>
        <source>New Tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="36"/>
        <source>Image Tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="37"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="70"/>
        <source>Remove Tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="77"/>
        <source>Negate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="179"/>
        <location filename="../tags.cpp" line="482"/>
        <location filename="../tags.cpp" line="491"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="179"/>
        <source>Failed to save tags to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="381"/>
        <source>Tagging </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="384"/>
        <source>Untagging </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="473"/>
        <source>Add a new tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="474"/>
        <source>Enter new tag name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="482"/>
        <source>No name entered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="491"/>
        <source>Tag </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="491"/>
        <source> already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="508"/>
        <source>Remove selected tags(s)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="509"/>
        <source>Remove tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="514"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="515"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <location filename="../imageview.cpp" line="626"/>
        <source>Clipboard</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="780"/>
        <source>Selection size: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="828"/>
        <source>No selection</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="828"/>
        <source>Hold down the Ctrl key and select a region using the mouse.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="958"/>
        <source>Saving...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="975"/>
        <location filename="../imageview.cpp" line="988"/>
        <location filename="../imageview.cpp" line="1021"/>
        <source>Error</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="975"/>
        <location filename="../imageview.cpp" line="1021"/>
        <source>Failed to save image.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="988"/>
        <source>Failed to save Exif metadata.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="993"/>
        <location filename="../imageview.cpp" line="1034"/>
        <source>Image saved.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="1005"/>
        <source>Save image as</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="1007"/>
        <source>Images</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>InfoView</name>
    <message>
        <location filename="../infoview.cpp" line="40"/>
        <source>Copy</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Phototonic</name>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Image Info</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="201"/>
        <source>Zoom</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <source>Mirroring</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>Transform</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <location filename="../mainwindow.cpp" line="253"/>
        <location filename="../mainwindow.cpp" line="801"/>
        <source>View</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Top</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Bottom</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Close Image</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Full Screen</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Preferences</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Exit</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Enlarge Thumbnails</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Shrink Thumbnails</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Cut</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Copy</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Copy to...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>Move to...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Delete</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Save</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Save As</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Copy Image Data</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>Paste Image Data</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <location filename="../mainwindow.cpp" line="3151"/>
        <source>Rename</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>Select All</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>About</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>Name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Time</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Size</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Type</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Reverse</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Show Hidden Files</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>Show Labels</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Small Icons</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Hide Dock Title Bars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>Show Toolbar</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Classic Thumbs</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Compact</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Squarish</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Reload</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Include Sub-folders</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Paste Here</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="465"/>
        <source>New Folder</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>Back</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="476"/>
        <source>Forward</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="482"/>
        <source>Go Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <location filename="../mainwindow.cpp" line="2717"/>
        <source>Slide Show</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>Next</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Previous</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="507"/>
        <source>First</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Last</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Random</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>Open</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Load Clipboard</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>Open With...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <source>Manage External Applications</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Add Bookmark</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Remove Bookmark</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Zoom Out</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Zoom In</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>Reset Zoom</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="563"/>
        <location filename="../mainwindow.cpp" line="1424"/>
        <source>Original Size</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>Keep Zoom</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Rotate 90 degree CCW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>Rotate 90 degree CW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Flip Horizontally</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>Flip Vertically</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>Cropping</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Crop to Selection</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="602"/>
        <source>Scale Image</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Rotate 1 degree CCW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Rotate 1 degree CW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="615"/>
        <source>Colors</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <source>Find Duplicate Images</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Disable</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="628"/>
        <source>Dual</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Triple</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Dual Vertical</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Quad</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Lock Transformations</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="654"/>
        <source>Move Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <source>Move Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>Move Up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Move Down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Invert Selection</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Filter by Name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Set Path</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="681"/>
        <source>&amp;File</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>&amp;Edit</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="705"/>
        <source>&amp;Go</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>&amp;View</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="720"/>
        <source>Sort By</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>&amp;Tools</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>&amp;Help</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="771"/>
        <source>Edit</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>Navigation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="808"/>
        <source>Filter</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>Image</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="871"/>
        <source>Initializing...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>File System</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="922"/>
        <source>Bookmarks</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1044"/>
        <source>&lt;p&gt;Image viewer and organizer&lt;/p&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1046"/>
        <source>Home page</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1047"/>
        <source>Bug reports</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <location filename="../mainwindow.cpp" line="1330"/>
        <location filename="../mainwindow.cpp" line="1638"/>
        <location filename="../mainwindow.cpp" line="1651"/>
        <location filename="../mainwindow.cpp" line="1761"/>
        <location filename="../mainwindow.cpp" line="1842"/>
        <location filename="../mainwindow.cpp" line="1902"/>
        <location filename="../mainwindow.cpp" line="2703"/>
        <location filename="../mainwindow.cpp" line="2983"/>
        <location filename="../mainwindow.cpp" line="2989"/>
        <location filename="../mainwindow.cpp" line="3006"/>
        <location filename="../mainwindow.cpp" line="3108"/>
        <location filename="../mainwindow.cpp" line="3164"/>
        <location filename="../mainwindow.cpp" line="3175"/>
        <location filename="../mainwindow.cpp" line="3235"/>
        <location filename="../mainwindow.cpp" line="3265"/>
        <location filename="../mainwindow.cpp" line="3304"/>
        <location filename="../mainwindow.cpp" line="3338"/>
        <location filename="../mainwindow.cpp" line="3349"/>
        <source>Error</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <source>Failed to start external application.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1128"/>
        <source>Invalid selection.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1330"/>
        <source>Failed to copy or move image.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1384"/>
        <source>Minimum zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1390"/>
        <location filename="../mainwindow.cpp" line="1408"/>
        <source>Zoom %1%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>Maximum zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1416"/>
        <source>Zoom Reset</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1431"/>
        <source>Zoom Locked</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1433"/>
        <source>Zoom Unlocked</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1442"/>
        <source>Transformations Locked</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1447"/>
        <source>Transformations Unlocked</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1459"/>
        <location filename="../mainwindow.cpp" line="1468"/>
        <location filename="../mainwindow.cpp" line="1525"/>
        <location filename="../mainwindow.cpp" line="1534"/>
        <source>Rotation %1°</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Flipped Vertically</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Unflipped Vertically</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1482"/>
        <source>Flipped Horizontally</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1482"/>
        <source>Unflipped Horizontally</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1507"/>
        <location filename="../mainwindow.cpp" line="1798"/>
        <source>No selection</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1578"/>
        <source>Mirroring Disabled</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1585"/>
        <source>Mirroring: Dual</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1592"/>
        <source>Mirroring: Triple</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1599"/>
        <source>Mirroring: Dual Vertical</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1606"/>
        <source>Mirroring: Quad</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1638"/>
        <source>Can not copy or move to </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1651"/>
        <source>Can not copy or move to the same folder</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>Copied</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>Moved</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1676"/>
        <location filename="../mainwindow.cpp" line="1870"/>
        <location filename="../mainwindow.cpp" line="3028"/>
        <source>%n image(s)</source>
        <translation>
            <numerusform>%n image</numerusform>
            <numerusform>%n images</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1739"/>
        <source>Permanently delete</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1740"/>
        <source>Delete image</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1744"/>
        <location filename="../mainwindow.cpp" line="1811"/>
        <location filename="../mainwindow.cpp" line="3289"/>
        <source>Yes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1745"/>
        <location filename="../mainwindow.cpp" line="1812"/>
        <location filename="../mainwindow.cpp" line="3290"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1758"/>
        <source>Deleted </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1761"/>
        <source>Failed to delete image</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1806"/>
        <source>Permanently delete selected images?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1807"/>
        <source>Delete images</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1842"/>
        <source>Failed to delete image.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1870"/>
        <source>Deleted</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1902"/>
        <source>Invalid Path:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2216"/>
        <source>Viewer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2232"/>
        <source>Docks and Toolbars</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2554"/>
        <source>No images</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2703"/>
        <source>Failed to open file &quot;%1&quot;, file not found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2718"/>
        <source>Slide show stopped</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2745"/>
        <source>Stop Slide Show</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2746"/>
        <source>Slide show started</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2983"/>
        <source>Can not move or copy images to this folder.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2989"/>
        <source>Destination folder is same as source.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2997"/>
        <source>Move &quot;%1&quot; to &quot;%2&quot;?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2998"/>
        <source>Move folder</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3006"/>
        <source>Failed to move folder.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3008"/>
        <source>Folder moved</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3108"/>
        <source>Failed to open folder:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3140"/>
        <source>Duplicate images in %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3153"/>
        <source>New name:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3164"/>
        <location filename="../mainwindow.cpp" line="3338"/>
        <source>Invalid name entered.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3175"/>
        <source>Failed to rename folder.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3208"/>
        <source>Invalid selection</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3220"/>
        <source>Rename Image</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3222"/>
        <source>Enter a new name for &quot;%1&quot;:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3235"/>
        <source>No name entered.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3265"/>
        <source>Failed to rename image.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3281"/>
        <source>Permanently delete &quot;%1&quot; and all of its contents?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3285"/>
        <source>Delete folder</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3304"/>
        <source>Failed to delete folder.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3308"/>
        <source>Removed &quot;%1&quot;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3326"/>
        <source>New Sub folder</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3327"/>
        <source>New folder name:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3349"/>
        <source>Failed to create new folder.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3354"/>
        <source>Created &quot;%1&quot;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3395"/>
        <source>Warning</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3395"/>
        <source>Cannot perform action with temporary image.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1555"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="813"/>
        <source>Scale Image</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="825"/>
        <source>Scale</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="829"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="845"/>
        <source>Original size:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="848"/>
        <source>Width:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="849"/>
        <source>Height:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="850"/>
        <source>Units:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="852"/>
        <source>New size:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="855"/>
        <source>Pixels</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="857"/>
        <source>Percent</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="862"/>
        <source>Lock aspect ratio</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="270"/>
        <source>Preferences</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="275"/>
        <source>Fit Large Images</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="276"/>
        <location filename="../dialogs.cpp" line="293"/>
        <source>Disable</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="278"/>
        <location filename="../dialogs.cpp" line="295"/>
        <source>By width</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="279"/>
        <location filename="../dialogs.cpp" line="296"/>
        <source>By height</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <location filename="../dialogs.cpp" line="297"/>
        <source>Stretch disproportionately</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Fit Small Images</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="323"/>
        <source>Exit instead of closing, when image is loaded from command line</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="327"/>
        <source>Wrap image list when reaching last or first image</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="331"/>
        <source>Default quality when saving images:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="341"/>
        <source>Enable GIF animation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="345"/>
        <source>Rotate image according to Exif orientation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="309"/>
        <location filename="../dialogs.cpp" line="371"/>
        <source>Background color:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="277"/>
        <location filename="../dialogs.cpp" line="294"/>
        <source>By width or height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="349"/>
        <source>Show image file name in viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="383"/>
        <source>Label color:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="395"/>
        <source>Background image:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="414"/>
        <source>Add space between thumbnails:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="425"/>
        <source>Show original size of images smaller than the thumbnail size</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="429"/>
        <source>Number of thumbnail pages to read ahead:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="438"/>
        <source>Rotate thumbnails according to Exif orientation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="452"/>
        <source>Delay between slides in seconds:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="462"/>
        <source>Show random images</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="472"/>
        <source>Startup folder</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="474"/>
        <source>Default, or specified by command line argument</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="475"/>
        <source>Remember last</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="476"/>
        <source>Specify:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="523"/>
        <source>Swap mouse left-click and middle-click actions</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="527"/>
        <source>Delete confirmation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="531"/>
        <source>Keyboard Shortcuts</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="545"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="550"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="562"/>
        <source>Viewer</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="566"/>
        <source>Thumbnails</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="570"/>
        <source>Slide Show</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="574"/>
        <source>General</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="674"/>
        <source>Choose Startup Folder</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="681"/>
        <source>Open File</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="682"/>
        <source>Images</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ShortcutsTable</name>
    <message>
        <location filename="../dialogs.cpp" line="170"/>
        <source>Action</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="171"/>
        <source>Shortcut</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>Delete shortcut</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="227"/>
        <location filename="../dialogs.cpp" line="239"/>
        <source>Set shortcut</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="228"/>
        <source>&quot;%1&quot; is reserved for shortcuts to external applications.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="240"/>
        <source>&quot;%1&quot; is already assigned to &quot;%2&quot; action.</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ThumbView</name>
    <message>
        <location filename="../thumbview.cpp" line="245"/>
        <source>General</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="247"/>
        <source>File name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="251"/>
        <source>Location</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="255"/>
        <source>Size</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="259"/>
        <source>Modified</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="264"/>
        <source>Format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="268"/>
        <source>Resolution</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="274"/>
        <source>Megapixel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="282"/>
        <source>Error</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="463"/>
        <location filename="../thumbview.cpp" line="684"/>
        <location filename="../thumbview.cpp" line="685"/>
        <source>%n image(s)</source>
        <translation>
            <numerusform>%n image</numerusform>
            <numerusform>%n images</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="465"/>
        <source>No images</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="297"/>
        <source>Selected %1 of%2</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="299"/>
        <source> %n image(s)</source>
        <translation>
            <numerusform> %n image</numerusform>
            <numerusform> %n images</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="683"/>
        <source>Scanned %1, displaying %2 (%3 and %4)</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="686"/>
        <source>%n original(s)</source>
        <translation>
            <numerusform>%n original</numerusform>
            <numerusform>%n originals</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="687"/>
        <source>%n duplicate(s)</source>
        <translatorcomment>%n duplicates</translatorcomment>
        <translation>
            <numerusform>%n duplicate</numerusform>
            <numerusform>%n duplicates</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="582"/>
        <source>Searching duplicate images...</source>
        <translation></translation>
    </message>
</context>
</TS>
